@@ -54,7 +54,7 @@ trap "rm -f $tmp; exit 1" 1 2 11 15
 $dialog \
 --title 'Compile-time options' \
 --separate-output \
---backtitle 'PureFTPd 1.0.7' \
+--backtitle 'PureFTPd 1.0.8' \
 --checklist 'Defaults should be fine for most users' \
 20 78 10 \
 'without-standalone' "Don't compile the standalone server code" off \
@@ -70,6 +70,7 @@ $dialog \
 'without-nonalnum' "Only allow minimal alpha-numeric characters" off \
 'without-globbing' "Don't include the globbing code" off \
 'without-sendfile' "Don't use zero-copy optimizations" off \
+'with-brokenrealpath' "If your C library has a broken realpath()" off \
 'with-minimal' "Build only a minimal server for embedded systems" off \
 'with-paranoidmsg' "Use paranoid, but not admin-friendly messages" off \
 'with-sysquotas' "Use system (not virtual) quotas" off \
@@ -78,6 +79,7 @@ $dialog \
 'with-altlog' "Support alternative log format (Apache-like)" on \
 'with-pam' 'Enable PAM authentication' off \
 'with-puredb' 'Support virtual (FTP-only) users' on \
+'with-extauth' 'Support external authentication modules' on \
 'with-cookie' "Support 'fortune' cookies" on \
 'with-throttling' "Support bandwidth throttling" on \
 'with-ftpwho' "Support the pure-ftpwho command" on \
@@ -99,7 +101,7 @@ done
 $dialog \
 --title 'Compile-time options' \
 --separate-output \
---backtitle 'PureFTPd 1.0.7' \
+--backtitle 'PureFTPd 1.0.8' \
 --radiolist 'Choose a language for server messages' \
 20 78 10 \
 'english' "This is the default" on \
@@ -123,7 +125,7 @@ cfgline="$cfgline --with-language=$z"
 
 $dialog \
 --title 'Compile-time options' \
---backtitle 'PureFTPd 1.0.7' \
+--backtitle 'PureFTPd 1.0.8' \
 --inputbox 'Installation prefix (/usr/local is not a bad idea)' \
 10 78 \
 '/usr/local' \
@@ -161,7 +163,7 @@ if [ -n "$gauge" ] ; then
   echo 100
 ) | $dialog \
 --title 'Compilation and installation' \
---backtitle 'PureFTPd 1.0.7' \
+--backtitle 'PureFTPd 1.0.8' \
 "$gauge" 'Please wait...' 10 78 10
 else  
   rm -f config.cache
