@@ -34,7 +34,7 @@ int main(void)
     do {
         curkey += (rand() & 0x6fff);
         snprintf(key, sizeof key, "%llu", curkey);
-        snprintf(data, sizeof data, "%llu", curkey ^ 0x12345678abcdef);
+        snprintf(data, sizeof data, "%llu", curkey ^ 0x12345678abcdefULL);
         if (puredbw_add_s(&dbw, key, data) != 0) {
             goto end;
         }
@@ -67,7 +67,7 @@ int main(void)
     do {
         curkey += (rand() & 0x6fff);
         snprintf(key, sizeof key, "%llu", curkey);
-        snprintf(data, sizeof data, "%llu", curkey ^ 0x12345678abcdef);
+        snprintf(data, sizeof data, "%llu", curkey ^ 0x12345678abcdefULL);
         if (puredb_find_s(&db, key, &retpos, &retlen) != 0) {
             fprintf(stderr, "The key wasn't found\n");
             goto end2;
