@@ -1,11 +1,12 @@
 #include <config.h>
 
-#ifdef WITH_LDAP
+#if defined(WITH_LDAP) || defined(WITH_MYSQL)
 
 #include "ftpd.h"
 #include "crypto.h"
 #include "crypto-sha1.h"
 #include "crypto-md5.h"
+
 #ifdef WITH_DMALLOC
 # include <dmalloc.h>
 #endif
