@@ -1,11 +1,11 @@
+#include <config.h>
 
 #define FAKECHROOT_FUNCS_DEFINITION 1
 
-#include <config.h>
-
 #ifdef WITH_VIRTUAL_CHROOT
 
 # include "ftpd.h"
+
 # ifdef WITH_DMALLOC
 #  include <dmalloc.h>
 # endif
@@ -16,20 +16,42 @@ static size_t chroot_len;
 
 int fakechroot(const char *path)
 {
+    char *z;
+    
     if (path == NULL || *path == 0) {
+# ifdef EINVAL
+        errno = EINVAL;
+# endif
         return -1;
     }
     if (chroot_base != NULL) {
         free(chroot_base);
+        chroot_base = NULL;
     }
-    chroot_len = strlen(path);
-    if (chroot_len >= sizeof curdir) {
-        return -1;
+    if (path[0] == '/' && path[1] == 0) {   /* chroot("/") => no chroot */
+        return 0;
     }
     if ((chroot_base = strdup(path)) == NULL) {
         return -1;
     }
     simplify(chroot_base);
+    z = chroot_base;
+    while (*z != 0) {
+        z++;
+    }
+    for (;;) {
+        z--;
+        if (z == chroot_base || *z != '/') {
+            break;
+        }
+        *z = 0;
+    }
+    if ((chroot_len = strlen(chroot_base)) >= sizeof curdir) {
+# ifdef ENAMETOOLONG
+        errno = ENAMETOOLONG;
+# endif
+        return -1;
+    }
     
     return 0;
 }
@@ -48,6 +70,9 @@ char *fakegetcwd(char *dir, size_t size)
     curdirchr = curdir + chroot_len;
     s = strlen(curdirchr);
     if (s <= (size_t) 0U) {
+# ifdef EFAULT
+        errno = EFAULT;
+# endif
         return NULL;
     }
     {
@@ -60,6 +85,9 @@ char *fakegetcwd(char *dir, size_t size)
     }
     s++;     
     if (s > size || s < (size_t) 2U) {
+# ifdef ENAMETOOLONG
+        errno = ENAMETOOLONG;
+# endif
         return NULL;
     }
     memcpy(dir, curdirchr, s);
@@ -71,7 +99,7 @@ static int fakexlate(char *curdirtmp, size_t sizeof_curdirtmp, const char *dir)
 {
     char *sl;     
     
-    strcpy(curdirtmp, curdir);        /* safe */
+    strcpy(curdirtmp, curdir);        /* flawfinder: ignore - safe */
     simplify(curdirtmp);
     loop:
     if (dir[0] == '.' && dir[1] == '.' &&
@@ -98,11 +126,17 @@ static int fakexlate(char *curdirtmp, size_t sizeof_curdirtmp, const char *dir)
         size_t curdirtmplen;
         
         if (strstr(dir, "..") != NULL) {
+# ifdef EPERM
+            errno = EPERM;
+# endif
             return -1;
         }
         dirlen = strlen(dir) + 1U;
         curdirtmplen = strlen(curdirtmp);
         if (curdirtmplen + dirlen >= sizeof_curdirtmp) {
+# ifdef ENAMETOOLONG
+            errno = ENAMETOOLONG;
+# endif
             return -1;
         }
         curdirtmp[curdirtmplen] = '/';
@@ -126,7 +160,7 @@ int fakechdir(const char *dir)
     if (chdir(curdirtmp) != 0) {
         return -1;
     }
-    strcpy(curdir, curdirtmp);        /* safe */
+    strcpy(curdir, curdirtmp);        /* flawfinder: ignore - safe */
     
     return 0;
 }
@@ -379,6 +413,23 @@ int fakerename(const char *oldpath, const char *newpath)
     return rename(curdirtmp, curdirtmp2);
 }
 
+/* 
+ * Promotion of mode_t is problematic. For instance, on MacOS X,
+ * mode_t is an unsigned short.
+ */
+
+# if SIZEOF_MODE_T <= 0
+#  define VA_ARG_MODE_T unsigned int
+# elif SIZEOF_MODE_T <= SIZEOF_INT
+#  define VA_ARG_MODE_T unsigned int
+# elif SIZEOF_MODE_T <= SIZEOF_LONG
+#  define VA_ARG_MODE_T unsigned long
+# elif SIZEOF_MODE_T <= SIZEOF_LONG_LONG
+#  define VA_ARG_MODE_T unsigned long long
+# else
+#  define VA_ARG_MODE_T mode_t
+# endif
+
 int fakeopen(const char *file, int flags, ...)
 {
     va_list va;
@@ -388,7 +439,7 @@ int fakeopen(const char *file, int flags, ...)
     va_start(va, flags);
     if (chroot_base == NULL) {
         if ((flags & O_CREAT) != 0) {
-            mode = va_arg(va, mode_t);
+            mode = va_arg(va, VA_ARG_MODE_T);
             va_end(va);
             return open(file, flags, mode);
         }
@@ -400,7 +451,7 @@ int fakeopen(const char *file, int flags, ...)
         return -1;
     }
     if ((flags & O_CREAT) != 0) {
-        mode = va_arg(va, mode_t);
+        mode = va_arg(va, VA_ARG_MODE_T);
         va_end(va);          
         return open(curdirtmp, flags, mode);
     }
@@ -409,6 +460,19 @@ int fakeopen(const char *file, int flags, ...)
     return open(curdirtmp, flags);
 }
 
+char *fakerealpath(const char *file, char *resolved_path)
+{
+    char curdirtmp[MAXPATHLEN];
+    
+    if (chroot_base == NULL) {
+        return realpath(file, resolved_path);
+    }
+    if (fakexlate(curdirtmp, sizeof curdirtmp, file) != 0) {
+        return NULL;
+    }
+    return realpath(curdirtmp, resolved_path);
+}
+
 # if STATFS_TYPE == 1
 int fakestatvfs64(const char *path, STATFS_STRUCT *str)
 # elif STATFS_TYPE == 2
