@@ -275,7 +275,7 @@ typedef struct FileInfo_ {
 #define FI_NAME(X) (*((X)->names_pnt) + (X)->name_offset)
 
 typedef enum {
-    ALTLOG_NONE, ALTLOG_CLF, ALTLOG_STATS
+    ALTLOG_NONE, ALTLOG_CLF, ALTLOG_STATS, ALTLOG_W3C
 } AltLogFormat;
 
 typedef struct AltLogPrefixes_ {
@@ -370,6 +370,10 @@ extern int opt_a, opt_C, opt_d, opt_F, opt_l, opt_R;
 # define UPLOADSCRIPT_PID_FILE "/var/run/pure-uploadscript.pid"
 #endif
 
+#ifndef AUTHD_PID_FILE
+# define AUTHD_PID_FILE "/var/run/pure-authd.pid"
+#endif
+
 #ifndef NON_ROOT_FTP
 # define DEFAULT_FTP_PORT_S "21"
 #else
@@ -405,11 +409,20 @@ the server may be insecure if a wrong value is set here.
 #endif
 
 #if defined(WITH_LDAP) || defined(WITH_MYSQL) || defined(WITH_PGSQL)
-# define MAX_DATA_SIZE (16 * 1024 * 1024)       /* Max memory usage - LDAP needs more */
+# define MAX_DATA_SIZE (16 * 1024 * 1024)       /* Max memory usage - SQL/LDAP need more */
 #else
 # define MAX_DATA_SIZE (8 * 1024 * 1024)       /* Max memory usage */
 #endif
 
+#if CONF_TCP_SO_RCVBUF < 65536
+# undef CONF_TCP_SO_RCVBUF
+# define CONF_TCP_SO_RCVBUF 65536
+#endif
+#if CONF_TCP_SO_SNDBUF < 65536
+# undef CONF_TCP_SO_SNDBUF
+# define CONF_TCP_SO_SNDBUF 65536
+#endif
+    
 #define DEFAULT_DL_CHUNK_SIZE (1 << 18)
 #define DEFAULT_UL_CHUNK_SIZE (CONF_TCP_SO_RCVBUF)
 #define MAX_UL_CHUNK_SIZE (CONF_TCP_SO_RCVBUF)
@@ -501,65 +514,65 @@ the server may be insecure if a wrong value is set here.
 #endif
        
 #ifdef STAT_MACROS_BROKEN
-#undef S_ISBLK
-#undef S_ISCHR
-#undef S_ISDIR
-#undef S_ISFIFO
-#undef S_ISLNK
-#undef S_ISMPB
-#undef S_ISMPC
-#undef S_ISNWK
-#undef S_ISREG
-#undef S_ISSOCK
+# undef S_ISBLK
+# undef S_ISCHR
+# undef S_ISDIR
+# undef S_ISFIFO
+# undef S_ISLNK
+# undef S_ISMPB
+# undef S_ISMPC
+# undef S_ISNWK
+# undef S_ISREG
+# undef S_ISSOCK
 #endif                            /* STAT_MACROS_BROKEN.  */
-
+    
 #ifndef S_IFMT
-#define S_IFMT 0170000
+# define S_IFMT 0170000
 #endif
 #if !defined(S_ISBLK) && defined(S_IFBLK)
-#define S_ISBLK(m) (((m) & S_IFMT) == S_IFBLK)
+# define S_ISBLK(m) (((m) & S_IFMT) == S_IFBLK)
 #endif
 #if !defined(S_ISCHR) && defined(S_IFCHR)
-#define S_ISCHR(m) (((m) & S_IFMT) == S_IFCHR)
+# define S_ISCHR(m) (((m) & S_IFMT) == S_IFCHR)
 #endif
 #if !defined(S_ISDIR) && defined(S_IFDIR)
-#define S_ISDIR(m) (((m) & S_IFMT) == S_IFDIR)
+# define S_ISDIR(m) (((m) & S_IFMT) == S_IFDIR)
 #endif
 #if !defined(S_ISREG) && defined(S_IFREG)
-#define S_ISREG(m) (((m) & S_IFMT) == S_IFREG)
+# define S_ISREG(m) (((m) & S_IFMT) == S_IFREG)
 #endif
 #if !defined(S_ISFIFO) && defined(S_IFIFO)
-#define S_ISFIFO(m) (((m) & S_IFMT) == S_IFIFO)
+# define S_ISFIFO(m) (((m) & S_IFMT) == S_IFIFO)
 #endif
 #if !defined(S_ISLNK) && defined(S_IFLNK)
-#define S_ISLNK(m) (((m) & S_IFMT) == S_IFLNK)
+# define S_ISLNK(m) (((m) & S_IFMT) == S_IFLNK)
 #endif
 #if !defined(S_ISSOCK) && defined(S_IFSOCK)
-#define S_ISSOCK(m) (((m) & S_IFMT) == S_IFSOCK)
+# define S_ISSOCK(m) (((m) & S_IFMT) == S_IFSOCK)
 #endif
 #if !defined(S_ISMPB) && defined(S_IFMPB)    /* V7 */
-#define S_ISMPB(m) (((m) & S_IFMT) == S_IFMPB)
-#define S_ISMPC(m) (((m) & S_IFMT) == S_IFMPC)
+# define S_ISMPB(m) (((m) & S_IFMT) == S_IFMPB)
+# define S_ISMPC(m) (((m) & S_IFMT) == S_IFMPC)
 #endif
 #if !defined(S_ISNWK) && defined(S_IFNWK)    /* HP/UX */
-#define S_ISNWK(m) (((m) & S_IFMT) == S_IFNWK)
+# define S_ISNWK(m) (((m) & S_IFMT) == S_IFNWK)
 #endif
-
+    
 #ifndef S_IEXEC
-#define S_IEXEC S_IXUSR
+# define S_IEXEC S_IXUSR
 #endif
-
+    
 #ifndef S_IXUSR
-#define S_IXUSR S_IEXEC
+# define S_IXUSR S_IEXEC
 #endif
 #ifndef S_IXGRP
-#define S_IXGRP (S_IEXEC >> 3)
+# define S_IXGRP (S_IEXEC >> 3)
 #endif
 #ifndef S_IXOTH
-#define S_IXOTH (S_IEXEC >> 6)
+# define S_IXOTH (S_IEXEC >> 6)
 #endif
 #ifndef S_IXUGO
-#define S_IXUGO (S_IXUSR | S_IXGRP | S_IXOTH)
+# define S_IXUGO (S_IXUSR | S_IXGRP | S_IXOTH)
 #endif
 
 #ifndef HAVE_MUNMAP
@@ -582,6 +595,7 @@ the server may be insecure if a wrong value is set here.
 # define _EXIT(X) _exit(X)
 #endif
 
-#include "fakechroot.h"     
-     
+#include "bsd-realpath.h"    
+#include "fakechroot.h"
+        
 #endif
