@@ -18,6 +18,9 @@
 #ifdef WITH_PUREDB
 # include "log_puredb.h"
 #endif
+#ifdef WITH_EXTAUTH
+# include "log_extauth.h"
+#endif
 #if !defined(NO_GETOPT_LONG) && !defined(HAVE_GETOPT_LONG)
 # include "gnu-getopt.h"
 #else
@@ -70,7 +73,7 @@ static const char *GETOPT_OPTIONS =
 #ifndef NO_STANDALONE
     "g:"
 #endif
-    "hHiI:jk:Kl:L:Mm:N"
+    "GhHiI:jk:Kl:L:Mm:N"
 #ifdef QUOTAS
     "n:"
 #endif
@@ -116,6 +119,7 @@ static struct option long_options[] = {
 # ifndef NO_STANDALONE
     { "pidfile", 1, NULL, 'g' },
 # endif
+    { "norename", 0, NULL, 'G' },    
     { "help", 0, NULL, 'h' },
     { "dontresolve", 0, NULL, 'H' },
     { "maxidletime", 1, NULL, 'I' },
@@ -168,6 +172,7 @@ static struct option long_options[] = {
 static const AltLogPrefixes altlogprefixes[] = {
     { "clf", ALTLOG_CLF },
     { "stats", ALTLOG_STATS },
+    { "w3c", ALTLOG_W3C },
     { NULL, ALTLOG_NONE }
 };
 
@@ -223,6 +228,9 @@ static Authentication auth_list[] = {
 #endif
 #ifdef WITH_PUREDB
     { "puredb", pw_puredb_parse, pw_puredb_check, pw_puredb_exit },   /* 5 */
+#endif
+#ifdef WITH_EXTAUTH
+    { "extauth", pw_extauth_parse, pw_extauth_check, pw_extauth_exit },   /* 6 */
 #endif
     { NULL, NULL, NULL, NULL }
 };
@@ -241,4 +249,11 @@ typedef struct Authentications_ {
 
 static Authentications *first_authentications, *last_authentications;
 
+#if defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined (__CYGWIN__)
+static struct passwd *fakegetpwnam(const char * const name);
+# define getpwnam(A) fakegetpwnam(A)
+# define getpwuid(A) fakegetpwnam(NULL)
+# define WIN32_ANON_DIR "/ftp"
+#endif
+
 #endif
