@@ -18,11 +18,19 @@ typedef struct FTPWhoEntry_ {
     struct sockaddr_storage local_addr;    
     time_t date;
     time_t xfer_date;
-    char account[9];
-    char filename[43];
     volatile off_t restartat;
     volatile off_t download_total_size;
-    volatile off_t download_current_size;
+    volatile off_t download_current_size;    
+    char account[9];
+#ifdef PAGE_SIZE
+# if PAGE_SIZE > 2048
+    char filename[PAGE_SIZE - 1024];
+# else
+    char filename[1024];
+# endif
+#else
+    char filename[1024];
+#endif
 } FTPWhoEntry;
 
 int ftpwho_initwho(void);
