@@ -31,8 +31,7 @@ GLOBAL0(signed char v6ready);                    /* IPv6 supported or not */
 GLOBAL(const size_t cmdsize, MAXPATHLEN + 16U);
 GLOBAL0(char cmd[MAXPATHLEN + 32U]);        /* command line - about 30 chars for command */
 GLOBAL0(char wd[MAXPATHLEN + 1U]);            /* current working directory */
-GLOBAL0(char *rd);                        /* root directory, for chroot'd environments */
-GLOBAL0(size_t rd_len);                    /* because rd is an ugly tmp variable */
+GLOBAL0(char *root_directory);                /* root directory, for chroot'd environments */
 GLOBAL0(signed char loggedin);                    /* != 0 if the user if logged in */
 GLOBAL0(char account[42]);                /* user login */
 GLOBAL0(char *renamefrom);
@@ -113,8 +112,6 @@ GLOBAL0(signed char daemonize);
 GLOBAL0(int shm_id);
 GLOBAL0(FTPWhoEntry *shm_data);
 GLOBAL0(FTPWhoEntry *shm_data_cur);
-GLOBAL(int sem_id, -1);
-GLOBAL(int sem_nb, -1);
 #endif
 
 #if defined(WITH_UPLOAD_SCRIPT) && !defined(NON_ROOT_FTP)
@@ -124,6 +121,7 @@ GLOBAL(int upload_pipe_lock, -1);
 #endif
 
 GLOBAL0(signed char create_home);
+GLOBAL0(signed char disallow_rename);
 
 GLOBAL0(size_t MAP_SIZE);
 GLOBAL0(size_t dl_chunk_size);
