@@ -2,14 +2,16 @@
 
 #ifdef WITH_MYSQL
 
-#include "ftpd.h"
-#include "parser.h"
-#include "log_mysql_p.h"
-#include "log_mysql.h"
-#include "messages.h"
-#ifdef WITH_DMALLOC
-# include <dmalloc.h>
-#endif
+# include "ftpd.h"
+# include "parser.h"
+# include "log_mysql_p.h"
+# include "log_mysql.h"
+# include "messages.h"
+# include "crypto.h"
+
+# ifdef WITH_DMALLOC
+#  include <dmalloc.h>
+# endif
 
 static int pw_mysql_validate_name(const char *name)
 {
@@ -302,7 +304,7 @@ void pw_mysql_check(AuthResult * const result,
     char *escaped_decimal_ip = NULL;    
     char *scrambled_password = NULL;
     int committed = 1;
-    int crypto_crypt = 0, crypto_mysql = 0, crypto_plain = 0;
+    int crypto_crypt = 0, crypto_mysql = 0, crypto_md5 = 0, crypto_plain = 0;
     unsigned long decimal_ip_num = 0UL;
     char decimal_ip[42];
     char hbuf[NI_MAXHOST];
@@ -389,10 +391,13 @@ void pw_mysql_check(AuthResult * const result,
     if (strcasecmp(crypto, PASSWD_SQL_ANY) == 0) {
         crypto_crypt++;
         crypto_mysql++;
+        crypto_md5++;
     } else if (strcasecmp(crypto, PASSWD_SQL_CRYPT) == 0) {
         crypto_crypt++;
     } else if (strcasecmp(crypto, PASSWD_SQL_MYSQL) == 0) {
         crypto_mysql++;
+    } else if (strcasecmp(crypto, PASSWD_SQL_MD5) == 0) {
+        crypto_md5++;
     } else {                           /* default to plaintext */
         crypto_plain++;
     }
@@ -428,6 +433,14 @@ void pw_mysql_check(AuthResult * const result,
             goto auth_ok;
         }
     }
+    if (crypto_md5 != 0) {
+        register const char *crypted;
+
+        if ((crypted = (const char *) crypto_hash_md5(password, 1)) != NULL &&
+            strcmp(crypted, spwd) == 0) {
+            goto auth_ok;
+        }
+    }    
     if (crypto_plain != 0) {
         if (*password != 0 &&    /* refuse null cleartext passwords */
             strcmp(password, spwd) == 0) {
