@@ -178,8 +178,14 @@ static int pw_puredb_parseline(char *line, const char * const pwd,
     if ((line = my_strtok2(line, *PW_LINE_SEP)) == NULL || *line == 0) {   /* pwd */
         return -1;
     }    
-    if (strcmp(line, (const char *) crypt(pwd, line)) != 0) {
-        return -1;
+    {
+        register const char *crypted;
+        
+        if ((crypted = (const char *) crypt(pwd, line)) == NULL ||
+            strcmp(line, crypted) != 0) {
+            
+            return -1;
+        }
     }
     if ((line = my_strtok2(NULL, *PW_LINE_SEP)) == NULL || *line == 0) {   /* uid */
         return -1;
