@@ -208,4 +208,8 @@
 #define MSG_QUOTA_SIZE "%llu Kbyte er brugt (%d%%) - autoriseret: %llu Kb"
 #define MSG_QUOTA_EXCEEDED "Quota grnse overskredet : %s bliver ikke gemt"
 #define MSG_AUTH_UNKNOWN "Ukendt godkendelses metode"
-#define MSG_PDB_BROKEN "Unable to read the indexed puredb file (or old format detected) - Try pure-pw mkdb"
+#define MSG_PDB_BROKEN "Kunne ikke lse den indexerede puredb fil\n(eller gammelt format fundet) - Prv pure-pw mkdb"
+#define MSG_ALIASES_ALIAS "%s is an alias for %s."
+#define MSG_ALIASES_UNKNOWN "Unknown alias %s."
+#define MSG_ALIASES_BROKEN_FILE "Damaged aliases file"
+#define MSG_ALIASES_LIST "The following aliases are available :"
