@@ -39,7 +39,7 @@
 #define MSG_ANONYMOUS_LOGGED_VIRTUAL "Utilisateur anonyme loggue sur FTP virtuel"
 #define MSG_USER_OK "Utilisateur %s OK. Veuillez taper votre mot de passe"
 #define MSG_CANT_DO_TWICE "Impossible dans cette session"
-#define MSG_UNABLE_SECURE_ANON "Impossible d'etablire une session FTP anonyme securisee"
+#define MSG_UNABLE_SECURE_ANON "Impossible d'etablir une session FTP anonyme securisee"
 #define MSG_BANDWIDTH_RESTRICTED "La bande-passante est soumise a des quotas"
 #define MSG_NO_PASSWORD_NEEDED "Pas besoin de mot de passe"
 #define MSG_NOTRUST "Desole, votre compte est inutilisable"
@@ -61,7 +61,7 @@
 #define MSG_CANT_PASV "Impossible d'ouvrir une connexion IPv6 avec la commande PASV. Utilisez EPSV s'il vous plait."
 #define MSG_CANT_PASSIVE "Impossible d'ouvrir une connexion passive"
 #define MSG_PORTS_BUSY "Tous les ports TCP reserves sont occupes"
-#define MSG_GETSOCKNAME_DATA "Impossible d'identifier le socket de donnees local"
+#define MSG_GETSOCKNAME_DATA "Impossible d'identifier la socket de donnees local"
 #define MSG_GETPEERNAME "Impossible d'identifier le socket local"
 #define MSG_INVALID_IP "Adresse invalide"
 #define MSG_NO_EPSV "Utilisez un client conforme a IPv6 avec le support EPSV"
@@ -70,8 +70,8 @@
 #define MSG_FXP "Transfert FXP: depuis %s vers %s"
 #define MSG_NO_DATA_CONN "Aucune connexion de donnees"
 #define MSG_ACCEPT_FAILED "La connexion ne peut etre acceptee"
-#define MSG_ACCEPT_SUCCESS "Connexion de donnee acceptee"
-#define MSG_CNX_PORT_FAILED "Impossible d'ouvrir une connexion de donnee sur le port %d"
+#define MSG_ACCEPT_SUCCESS "Connexion de donnees acceptee"
+#define MSG_CNX_PORT_FAILED "Impossible d'ouvrir une connexion de donnees sur le port %d"
 #define MSG_CNX_PORT "Connexion au port %d"
 #define MSG_ANON_CANT_MKD "Les utilisateurs anonymes ne sont pas autorises a creer des repertoires"
 #define MSG_ANON_CANT_RMD "Les utilisateurs anonymes ne sont pas autorises a supprimer des repertoires"
@@ -129,7 +129,7 @@
 #define MSG_SANITY_FILE_FAILURE "Nom de fichier interdit: %s"
 #define MSG_MKD_FAILURE "Ne peut creer le repertoire"
 #define MSG_MKD_SUCCESS "Repertoire cree"
-#define MSG_RMD_FAILURE "Ne peut detruire le repertoire"
+#define MSG_RMD_FAILURE "Impossible de detruire le repertoire"
 #define MSG_RMD_SUCCESS "Repertoire supprime"
 #define MSG_TIMESTAMP_FAILURE "Ne peut obtenir de timbre horodateur"
 #define MSG_MODE_ERROR "Seuls les modes ASCII et binaires sont supportes"
