@@ -22,6 +22,7 @@ int main(void)
 #    include <getopt.h>
 #  endif
 # endif
+
 # ifdef WITH_DMALLOC
 #  include <dmalloc.h>
 # endif
@@ -499,7 +500,7 @@ static void help(void)
     exit(EXIT_SUCCESS);
 }
 
-static int closedesc(void)
+static int closedesc_but1(void)
 {
     int fodder;
     
@@ -507,8 +508,10 @@ static int closedesc(void)
     if ((fodder = open("/dev/null", O_RDONLY)) == -1) {
         return -1;
     }
-    (void) dup2(0, fodder);
-    (void) close(fodder);
+    (void) dup2(fodder, 0);
+    if (fodder > 0) {
+        (void) close(fodder);
+    }
     if (fcntl(1, F_GETFD) == -1) {
         return -1;
     }
@@ -516,8 +519,10 @@ static int closedesc(void)
         if ((fodder = open("/dev/null", O_WRONLY)) == -1) {
             return -1;
         }
-        (void) dup2(2, fodder);
-        (void) close(fodder);
+        (void) dup2(fodder, 2);
+        if (fodder > 2) {
+            (void) close(fodder);
+        }
     }
     return 0;
 }
@@ -543,7 +548,7 @@ int main(int argc, char *argv[])
     if (argc < 0) {
         return -1;
     }
-    if (closedesc() < 0) {
+    if (closedesc_but1() < 0) {
         return -2;
     }
 #ifdef HAVE_SETLOCALE
