@@ -1145,7 +1145,7 @@ static void do_mkdb(const char *dbfile, const char * const file)
     fclose(fp);
 }
 
-static void init_rand(void)
+static void init_zrand(void)
 {
     struct timeval tv;
     struct timezone tz;
@@ -1200,8 +1200,13 @@ int main(int argc, char *argv[])
     pwinfo.has_dl_ratio = 0;
     pwinfo.has_time = 0;
     pwinfo.time_begin = pwinfo.time_end = 0U;
-    pwinfo.uid = (uid_t) 0;
-    pwinfo.gid = (gid_t) 0;
+#if defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined (__CYGWIN__)
+    pwinfo.uid = (uid_t) 42U;
+    pwinfo.gid = (gid_t) 42U;
+#else
+    pwinfo.uid = (uid_t) 0U;
+    pwinfo.gid = (gid_t) 0U;
+#endif
     
     argv++;
     argc--;
@@ -1415,7 +1420,7 @@ int main(int argc, char *argv[])
         }
     }
     (void) umask(0177);
-    init_rand();
+    init_zrand();
     if (strcasecmp(action, "useradd") == 0) {
         do_useradd(file, &pwinfo);
         if (with_mkdb != 0) {
