@@ -1,4 +1,5 @@
 #include <config.h>
+
 #include "ftpd.h"
 #include "quotas.h"
 #if !defined(NO_GETOPT_LONG) && !defined(HAVE_GETOPT_LONG)
@@ -8,6 +9,7 @@
 #  include <getopt.h>
 # endif
 #endif
+
 #ifdef WITH_DMALLOC
 # include <dmalloc.h>
 #endif
@@ -18,6 +20,7 @@ static const char *startpath;
 static const char *user;
 static unsigned long long total_size;
 static unsigned long long total_files;
+static signed char isroot;
 
 /*
  * To avoid races/loop attacks, we keep track of inode and
@@ -57,7 +60,7 @@ static int traversal(const char * const s)
             close(fd);
             return -1;
         }
-        (void)fchmod(fd, st.st_mode | 0500);
+        (void) fchmod(fd, st.st_mode | 0500);
         close(fd);
         if ((fd = open(s, O_RDONLY | O_DIRECTORY)) == -1) {
             return -1;
@@ -111,12 +114,15 @@ static int traversal(const char * const s)
              de->d_name[2] == 0)) {
             continue;
         }
+        if (strcmp(de->d_name, QUOTA_FILE) == 0) {
+            continue;
+        }
         sizeof_buf = slen + strlen(de->d_name);
         if ((alloca_buf = ALLOCA(sizeof_buf)) == NULL) {
             continue;
         }
         snprintf(alloca_buf, sizeof_buf, "%s/%s", s, de->d_name);
-        if (lstat(alloca_buf, &st) == 0) {
+        if (stat(alloca_buf, &st) == 0) {
             if (S_ISDIR(st.st_mode)) {
                 if (traversal(alloca_buf) == 0) {
                     total_files++;
@@ -144,20 +150,42 @@ static void help(void)
     exit(EXIT_SUCCESS);
 }
 
-static int changeuidgid(void)
+static int doinitsupgroups(const char *user, const uid_t uid, const uid_t gid)
 {
-#ifdef HAVE_INITGROUPS
-    if (user != NULL) {
-        if (initgroups(user, gid) < 0) {
+#ifndef NON_ROOT_FTP
+# ifdef HAVE_SETGROUPS
+    if (setgroups(sizeof(gid) / sizeof(gid_t), &gid) != 0) {
+        return -1;
+    }
+# else
+    (void) gid;
+# endif
+# ifdef HAVE_INITGROUPS            
+    if (user == NULL) {
+        const struct passwd * const lpwd = getpwuid(uid);
+        
+        if (lpwd != NULL && lpwd->pw_name != NULL) {
+            user = lpwd->pw_name;
+        } else {        
             return -1;
         }
     }
+    initgroups(user, gid);
+# else
+    (void) user;
+    (void) uid;
+# endif
+#else
+    (void) user;
+    (void) uid;
+    (void) gid;    
 #endif
-    if (
-#ifdef HAVE_SETGROUPS
-        setgroups(1U, &gid) ||
-#endif
-        setgid(gid) || setegid(gid) ||
+    return 0;
+}
+
+static int changeuidgid(void)
+{
+    if (setgid(gid) || setegid(gid) ||
         setuid(uid) || seteuid(uid) || chdir("/")) {
         return -1;
     }
@@ -238,13 +266,12 @@ int main(int argc, char *argv[])
 {
     int fodder;
 
-#ifndef NON_ROOT_FTP
-    if (geteuid() != (uid_t) 0) {
-        puts("You must be root to run this. Sorry.");
-        return 1;
-    }
-#endif
-    
+    if (geteuid() == (uid_t) 0) {
+        isroot = 1;
+    } else {
+        uid = geteuid();
+        gid = getegid();
+    }    
     if (argc < 0) {
         return -1;
     }
@@ -331,16 +358,28 @@ int main(int argc, char *argv[])
         fprintf(stderr, "Invalid/insecure gid - must be > 0\n");
         return -2;
     }
-    if (chdir(startpath) != 0 || chroot(startpath) != 0 || chdir("/") != 0) {
-        fprintf(stderr, "Can't chroot to [%s]: [%s]\n",
+    if (isroot != 0) {
+        if (doinitsupgroups(NULL, uid, gid) 
+#if defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined (__CYGWIN__)            
+            & 0
+#endif
+            != 0 ||
+            chdir(startpath) != 0 || 
+            chroot(startpath) != 0 || chdir("/") != 0) {
+            fprintf(stderr, "Can't chroot to [%s]: [%s]\n",
+                    startpath, strerror(errno));
+            return -3;
+        }
+        if (changeuidgid() < 0) {
+            fprintf(stderr, "Can't switch uid/gid: [%s]\n", strerror(errno));
+            return -3;
+        }        
+    } else if (chdir(startpath) != 0) {
+        fprintf(stderr, "Can't enter directory [%s]: [%s]\n",
                 startpath, strerror(errno));
         return -3;
     }
-    if (changeuidgid() < 0) {
-        fprintf(stderr, "Can't switch uid/gid: [%s]\n", strerror(errno));
-        return -3;
-    }
-    if (traversal("/") < 0) {
+    if (traversal(isroot != 0 ? "/" : "./") < 0) {
         fprintf(stderr, "Unable to traverse [%s]: [%s]\n",
                 startpath, strerror(errno));
         if (nodes != NULL) {
@@ -351,10 +390,15 @@ int main(int argc, char *argv[])
     if (nodes != NULL) {
         free(nodes);
     }
-    if (writequota("/" QUOTA_FILE) < 0) {
-        fprintf(stderr, "Unable to update the quota file ("
-                QUOTA_FILE "): [%s]\n", strerror(errno));
-        return -5;
+    if (isroot != 0) {
+        if (writequota("/" QUOTA_FILE) < 0) {
+            err_writequota:
+            fprintf(stderr, "Unable to update the quota file ("
+                    QUOTA_FILE "): [%s]\n", strerror(errno));
+            return -5;
+        }
+    } else if (chdir(startpath) != 0 || writequota(QUOTA_FILE) < 0) {
+        goto err_writequota;
     }
 
     return 0;
