@@ -16,6 +16,10 @@ int main(void)
 # include "upload-pipe.h"
 # include "pure-uploadscript_p.h"
 
+#ifdef WITH_DMALLOC
+# include <dmalloc.h>
+#endif
+
 static inline void setcloexec(const int fd)
 {
     fcntl(fd, F_SETFD, FD_CLOEXEC);
@@ -126,11 +130,37 @@ static char *checkvirtual(char *path)
     return buf;
 }
 
+static int closedesc_all(const int closestdin)
+{
+    int fodder;
+    
+    if (closestdin != 0) {
+        (void) close(0);
+        if ((fodder = open("/dev/null", O_RDONLY)) == -1) {
+            return -1;
+        }
+        (void) dup2(fodder, 0);
+        if (fodder > 0) {
+            (void) close(fodder);
+        }
+    }
+    if ((fodder = open("/dev/null", O_WRONLY)) == -1) {
+        return -1;
+    }
+    (void) dup2(fodder, 1);
+    (void) dup2(1, 2);
+    if (fodder > 2) {
+        (void) close(fodder);
+    }
+    
+    return 0;
+}
+
 static void dodaemonize(void)
 {
     pid_t child;
     
-    if (daemonize) {
+    if (daemonize != 0) {
         if ((child = fork()) == (pid_t) -1) {
             perror("Daemonization failed - fork");
             return;
@@ -140,26 +170,15 @@ static void dodaemonize(void)
             if (setsid() == (pid_t) -1) {
                perror("Daemonization failed : setsid");
             }
-            chdir("/");
-            if (isatty(1)) {
-                close(1);
-            }
-            if (isatty(2)) {
-                close(2);
-            }
+            (void) chdir("/");
+            (void) closedesc_all(0);
         }
     }    
 }
 
 static int init(void)
 {
-    close(0);    
-    if (!isatty(1) && close(1) < 0) {
-        return -1;
-    }
-    if (!isatty(2) && close(2) < 0) {
-        return -1;
-    }
+    (void) close(0);
     if (geteuid() != (uid_t) 0) {
         fprintf(stderr, "Sorry, but you have to be r00t to run this program\n");
         return -1;
@@ -350,11 +369,9 @@ static int run(const char * const who, const char * const file,
         /* Yes, there's already the cloexec flag on this fd,
          * but it's really important to close it. Be paranoid.
          */
-        if (close(upload_pipe_fd) < 0) {
+        if (close(upload_pipe_fd) < 0 || closedesc_all(1) < 0) {
             _exit(EXIT_FAILURE);
         }
-        close(1);
-        close(2);
         fillenv(who, &st);
         execl(script, script, file, NULL);
         _exit(EXIT_FAILURE);
@@ -420,9 +437,6 @@ int main(int argc, char *argv[])
     char *who;
     char *file;
     
-    (void) argc;
-    (void) argv;
-    
 #ifdef HAVE_SETLOCALE
 # ifdef LC_MESSAGES
     (void) setlocale(LC_MESSAGES, "");
@@ -457,6 +471,12 @@ int main(int argc, char *argv[])
         (void) unlink(PID_FILE);
         return -1;
     }
+#ifdef SIGPIPE
+    signal(SIGPIPE, SIG_IGN);
+#endif
+#ifdef SIGCHLD
+    signal(SIGCHLD, SIG_DFL);
+#endif
     for (;;) {
         if (readpipe(upload_pipe_fd, &who, &file) != 0) {
             continue;
